from .Steam import Steam
from .VK import VK
from .Origin import Origin
from .Warface import Warface
from .Uplay import Uplay
from .SocialClub import SocialClub
from .Fortnite import Fortnite
from .Instagram import Instagram
from .Battlenet import Battlenet
from .EpicGames import EpicGames
from .Valorant import Valorant
from .WorldOfTanks import WorldOfTanks
from .Blitz import Blitz
from .Supercell import Supercell
from .GenshinImpact import GenshinImpact
from .EscapeFromTarkov import EscapeFromTarkov
from .VPN import VPN
from .TikTok import TikTok
from .Discord import Discord
from .Cinema import Cinema
from .Telegram import Telegram
from .YouTube import YouTube
from .Spotify import Spotify
from .WarThunder import WarThunder

