INCOME = 'income'
COST = 'cost'
REFILLED_BALANCE = 'refilled_balance'
WITHDRAWAL_BALANCE = 'withdrawal_balance'
PAID_ITEM = 'paid_item'
SOLD_ITEM = 'sold_item'
MONEY_TRANSFER = 'money_transfer'
RECEIVING_MONEY = 'receiving_money'
INTERNAL_PURCHASE = 'internal_purchase'
